-- TODO move to pgtap

DROP TABLE edges;
DROP TABLE vertices;
CREATE TABLE edges (
    id integer,
    source integer,
    target integer,
    cost integer,
    the_geom geometry(MultiLineString)
);



INSERT INTO edges (id, source, target, cost, the_geom) VALUES
(664, 75242, 13078, 1, '01050000000100000001020000000500000006BB5C440B595D413FE94F59BAA125410134DD6412595D41A025BB1FD6A125413849F7A815595D41640C555DEBA12541336449FE18595D41899CBB7916A225418F8280C419595D412B03161742A22541'),
(700, 41613, 6810, 1, '010500000001000000010200000004000000E44CC814E05C5D41C9DAE107B8AB254139C51DD7E25C5D41B9326524F9AB25415226091BE65C5D415F2F44630EAC25414C05189BEA5C5D411C439CCD14AC2541'),
(716, 45339, 41613, 1, '01050000000100000001020000000500000064F3864EEB5C5D410656760257AB254164869F7DE75C5D41AB83AD0C5FAB25414810CFBDE35C5D4189D7B9F57CAB2541EA0FD53FE15C5D41DA0C855493AB2541E44CC814E05C5D41C9DAE107B8AB2541'),
(729, 63998, 71809, 1, '010500000001000000010200000005000000C15382C3F4595D41541258A89298254182F9F3AAEF595D411F9411F49A982541A93E045CE9595D4117D3F75EB9982541CB2C54BCE3595D4194343A3EE6982541D013470AE2595D41E91170852F992541'),
(774, 58520, 17561, 1, '0105000000010000000102000000020000006146E653205C5D41042E827257AF25412548EA461B5C5D415341AA516EAF2541'),
(812, 18110, 11146, 1, '010500000001000000010200000003000000F6962046275C5D41D7CC99B77EA925418DD83F109B5C5D41C0DC291368A9254144A59163EA5C5D41A9AF309358A92541'),
(813, 5165, 11146, 1, '010500000001000000010200000003000000F6962046275C5D41D7CC99B77EA925418DD83F109B5C5D41C0DC291368A9254144A59163EA5C5D41A9AF309358A92541'),
(961, 16837, 52078, 1, '010500000001000000010200000003000000B150FCDA2E595D4137257F2B449925417658D79C1F595D41166D6DA46B9925416045BCF119595D41052B9CEF89992541'),
(962, 6869, 52078, 1, '010500000001000000010200000003000000B150FCDA2E595D4137257F2B449925417658D79C1F595D41166D6DA46B9925416045BCF119595D41052B9CEF89992541'),
(1214, 16837, 30525, 1, '010500000001000000010200000002000000B150FCDA2E595D4137257F2B449925416697657D3F595D41404D85E540992541'),
(1215, 6869, 30525, 1, '010500000001000000010200000002000000B150FCDA2E595D4137257F2B449925416697657D3F595D41404D85E540992541'),
(1297, 31425, 41133, 1, '010500000001000000010200000002000000062AD9566F5B5D41D18BD5FBC1A625410AA3ACE8705B5D41F4F6CFD493A92541'),
(1298, 19402, 41133, 1, '010500000001000000010200000002000000062AD9566F5B5D41D18BD5FBC1A625410AA3ACE8705B5D41F4F6CFD493A92541'),
(736, 45624, 12545, 1, '01050000000100000001020000000900000007DBC451CB575D4194DDC9238FA72541BA3E82B9CA575D41A30CA3D89DA725416D718B6ECB575D411DA91A97B3A725416BCC59C7CC575D41EEF43F35C9A72541E9DE3811D0575D41A135B2BCE5A7254199821F97D4575D41CF01FB6EF3A72541234EF9C9D7575D41434662CDF2A725414F7761E2DC575D413B0B9380EAA725411CF6F365DF575D41684AC76ADBA72541'),
(859, 24891, 10550, 1, '01050000000100000001020000000E000000A0155A97095C5D4184299F5CEC9C2541F3F5F406FF5B5D4103FD3A8D549D2541380BDFEEF65B5D41891898149F9D2541D16F992BE95B5D411E2F8EE5079E2541BB5E34F0CC5B5D417CD3F4C8C39E2541024B71269F5B5D419A8801D3F79F2541FF5C3C5F965B5D41149037E633A02541009FF24C8E5B5D41B73331B885A02541D80472DE865B5D41CC271D6AD7A0254157EFCAB1805B5D418FE29F9121A1254126B6DB8A7A5B5D418ADA6B0373A125411B83E8B6755B5D416A1B9BC9D2A12541936B27BD725B5D413CCCBB501CA22541F34B87FF705B5D411737270357A22541'),
(1633, 10550, 19402, 1, '010500000001000000010200000006000000F34B87FF705B5D411737270357A22541010A9E476F5B5D41314BD8FF98A225415D4F8FA66D5B5D41BAE19E25F8A22541BF9BB4B46C5B5D416967DABF65A32541BED33E496D5B5D41739AE44A23A42541062AD9566F5B5D41D18BD5FBC1A62541'),
(1639, 10550, 31425, 1, '010500000001000000010200000006000000F34B87FF705B5D411737270357A22541010A9E476F5B5D41314BD8FF98A225415D4F8FA66D5B5D41BAE19E25F8A22541BF9BB4B46C5B5D416967DABF65A32541BED33E496D5B5D41739AE44A23A42541062AD9566F5B5D41D18BD5FBC1A62541'),
(1664, 47608, 5165, 1, '010500000001000000010200000002000000D9912A6FF35B5D4184BF089181A92541F6962046275C5D41D7CC99B77EA92541'),
(1845, 11146, 35635, 1, '01050000000100000001020000000300000044A59163EA5C5D41A9AF309358A92541E71DED03145D5D415F64C0085FA925414783C1C9295D5D41333BD41362A92541'),
(1861, 11146, 64473, 1, '01050000000100000001020000000300000044A59163EA5C5D41A9AF309358A92541E71DED03145D5D415F64C0085FA925414783C1C9295D5D41333BD41362A92541'),
(43627, 75308, 7312, 1, '010500000001000000010200000006000000DABDD22A19575D41BCC43DC78BAA2541C66C4C5C19575D4176134FA399AB2541CE0E380919575D414A3759D3FFAB2541A640074C17575D41FEC58C863AAC254171598B4114575D41EB213A306EAC2541088ED1260E575D415CB25439CEAC2541'),
(43674, 7312, 54278, 1, '010500000001000000010200000008000000088ED1260E575D415CB25439CEAC25412817B3D819575D41CEFBCB4406AD254199E3665520575D41854B2F2A22AD25410D7765BD28575D41CEB37FAE3DAD25415C1591902E575D415D2F066A52AD254154E863C331575D417F9437C851AD2541387762673B575D41E69B58775EAD2541C76ABCA155575D41800CC84859AD2541'),
(43748, 8369, 62998, 1, '01050000000100000001020000000B0000008EC3155AC1575D41AF53EFAA5D9D2541D29043DDA5575D41B5BB4D636A9D2541C257683B9E575D4194D1D07B7A9D2541A2777E8D8E575D41576ADAB3E39D2541647C9F2981575D41CF4A7FEFF49D2541E81CBE7079575D41921314DFE79D25418B65F56165575D41E6662EE3A29D2541655D9D2434575D41EF2DB6E8B39D2541B4F5D9B128575D41051D010ECC9D25417B66861015575D41AD59AE95119E2541F5DB04EE00575D418DF770FB829E2541'),
(2483, 25021, 17561, 1, '0105000000010000000102000000050000000627ABFE0A5C5D41B24734AD12AF254153B6E6110D5C5D41B39AFC5445AF2541A1D8C6B70F5C5D419C0DE7FD61AF25418E7800F6125C5D41F14F3AF26FAF25412548EA461B5C5D415341AA516EAF2541'),
(1654, 7177, 58358, 1, '010500000001000000010200000016000000D3232A15885C5D415F32A3CF7D8F2541E68BE926825C5D416517732718902541EDE4CF89785C5D417D014647E690254121711E12705C5D41B99C7A698891254135A58CE0605C5D41AA5EC0FB919225411A010C374C5C5D415817E473FB932541D6D501113D5C5D41AC86EF9A1395254154CB802C325C5D4192281FFBE1952541A580ABC52C5C5D41C215C6BF5796254192DF7E39265C5D4181192382F9962541A84DB750235C5D41E394D8E7589725415D6D6E11215C5D4181D5C977BF9725417EA4EF751F5C5D41F850B1E725982541EBE936C61C5C5D4151401D34CE982541E03726FC1B5C5D4188F924D66E9925410BDEA8871B5C5D4151273CD27C9A2541281C0A2E1B5C5D41ED6ECBB7DB9A2541EB86ACA3195C5D410CE68506589B2541A55FB55E175C5D4153CD364CB79B2541D610E3D7135C5D41044B441C1E9C25410C4795A70F5C5D41938819C27D9C2541A0155A97095C5D4184299F5CEC9C2541'),
(3725, 19613, 14977, 1, '010500000001000000010200000003000000D367748CA5595D41DACBD4063A9B2541C5017C9CA9595D413813462C829B25415ED2A46DAB595D41789F3CE2309C2541'),
(3734, 18596, 19613, 1, '0105000000010000000102000000040000000949C204AB595D41464214563A992541BFE105A2AB595D41A13A1CB5D29A2541FAC1DA7CAA595D419AE919B3FE9A2541D367748CA5595D41DACBD4063A9B2541'),
(4309, 23765, 46445, 1, '010500000001000000010200000002000000F7EED850E2595D41AF48B557C0A52541CD6FD5E0CC595D4154BCE2AD2AA62541'),
(4331, 18596, 71809, 1, '0105000000010000000102000000020000000949C204AB595D41464214563A992541D013470AE2595D41E91170852F992541'),
(3721, 19613, 11736, 1, '01050000000100000001020000000B000000D367748CA5595D41DACBD4063A9B2541B65242F09D595D4125660F68519B25418683A5E696595D413ACB4FCA529B25410B8EFDD27F595D41C8C749BD489B254108A660C978595D4111AC9F1F4A9B25410C7D22FC66595D4116C7FA18729B25411147FF2541595D418B0F0D5D5C9B25414CA861AD35595D416771B2356D9B254111DDF0A729595D41522CAF579B9B254150366BFC1A595D4141BD9ED1AC9B25411448CDD103595D4139CEAC9C859B2541'),
(43510, 55040, 37174, 1, '010500000001000000010200000002000000EE07D0F919575D413FCD069CE6A52541BC09BFD51B575D41E0486BEF0FA92541'),
(43639, 55041, 22534, 1, '010500000001000000010200000002000000EF2FE13AF5575D41B982815260AA2541DB72458C54585D41EA34E6854DAA2541'),
(43646, 58868, 28506, 1, '0105000000010000000102000000020000002984B2D0F6575D41ADE6FB2A32AD25412558D3A2FC575D41C18FB44D92B42541'),
(43652, 74969, 29224, 1, '0105000000010000000102000000020000001EE947AC6F575D4161AAD2D185AF254190A2BD1FDF565D413A5244AEA9AF2541'),
(43656, 7312, 30149, 1, '010500000001000000010200000003000000088ED1260E575D415CB25439CEAC25415859ED06F4565D416E7BAB1BC4AD25416E06E5F9E6565D419BFE12B242AE2541'),
(43658, 64813, 34773, 1, '010500000001000000010200000005000000A5F28F94C5575D414611AE2D43AD2541622CB583B1575D41D059DE70CAAD254105254E7E93575D410F3C05F5DEAD254198B21F958A575D413664454EEFAD25412E47E7BB7C575D410FC664FC3AAE2541'),
(43660, 54278, 34773, 1, '010500000001000000010200000004000000C76ABCA155575D41800CC84859AD25413C15C06268575D41C0AC033B97AD254162E785E770575D41DDE4E232D7AD25412E47E7BB7C575D410FC664FC3AAE2541'),
(43672, 42892, 54278, 1, '01050000000100000001020000000500000074241EB762575D4103E37FBD15AC2541A857D9A65F575D41CD9CD21C42AC2541B05A5AD85D575D41E9CD2FF166AC254188EF9C715B575D4102BF6D7A9AAC2541C76ABCA155575D41800CC84859AD2541'),
(43676, 55041, 58868, 1, '010500000001000000010200000002000000EF2FE13AF5575D41B982815260AA25412984B2D0F6575D41ADE6FB2A32AD2541'),
(43678, 11530, 64813, 1, '01050000000100000001020000000300000089077111C0575D416B24CEB7F4AB2541CAD678DEBD575D41E90C54DD69AC2541A5F28F94C5575D414611AE2D43AD2541'),
(43682, 74969, 65458, 1, '0105000000010000000102000000040000001EE947AC6F575D4161AAD2D185AF2541268247B472575D412622FC671EB025410020AFBE76575D4104F84B425FB02541F21269077E575D41BAF46E0FAEB02541'),
(43692, 7303, 74220, 1, '01050000000100000001020000000400000042ACE5A5BE575D41ECFD030ED5AF2541F5FFBCCBBD575D41ADD1B1D15FB025414E484214BC575D4150DD0DCFA1B02541CB124177B8575D415EF1A877EBB02541'),
(43694, 34773, 74969, 1, '0105000000010000000102000000060000002E47E7BB7C575D410FC664FC3AAE254105B3544875575D41EC51256785AE2541EFF20FFC70575D41C38EAA9BC0AE25417C7DD8A06E575D41DFAC6BB902AF2541426A66256E575D4175C19CE135AF25411EE947AC6F575D4161AAD2D185AF2541'),
(43696, 9427, 75308, 1, '010500000001000000010200000007000000D675C8D4FB555D41C426E6F0BCAA2541D8C311E450565D4103349CCDA4AA2541212DD05A75565D416E110C969DAA25416E0E068A98565D411D73CF9F96AA2541D246543DD0565D41100A29329AAA254176588A6CF3565D4151CE303D93AA2541DABDD22A19575D41BCC43DC78BAA2541'),
(43698, 46917, 8175, 1, '01050000000100000001020000000400000013BE0D7BB5575D410BDF88B03F9725412621E9CAE6575D41BC22451F849A2541F82266FAF7575D41A16C4857039C2541CEC48C3604585D419D31155AEA9C2541'),
(43700, 8175, 8369, 1, '010500000001000000010200000003000000CEC48C3604585D419D31155AEA9C25416A906ABED7575D41784AAC3F599D25418EC3155AC1575D41AF53EFAA5D9D2541'),
(43704, 62043, 10871, 1, '010500000001000000010200000002000000D96E508975575D41B7AB3A26279825417D205F1E41575D41195F7C1740982541'),
(43706, 46917, 10871, 1, '01050000000100000001020000000A00000013BE0D7BB5575D410BDF88B03F97254150F90AB2A7575D410544B3730196254164CD04B3A3575D41B9D8DF2DCF95254158E1D49D9C575D41EBDF04FDC1952541E16832D172575D41769D54D65496254132DAB7DE4A575D4112D77E70D19625419ED375D745575D41485C5F9CEF962541CF9BCB9041575D412F2C321B32972541A4FD8B7140575D41C7A6B863659725417D205F1E41575D41195F7C1740982541'),
(43708, 60251, 15590, 1, '01050000000100000001020000000200000046A3729573575D41AE46C17EE3A525418DDB97CF75575D414949B836B5A82541'),
(43714, 48344, 37263, 1, '0105000000010000000102000000060000004269057842575D417EBC077FF59925418F052DDE11575D41CA34DF64069A254129A4F5EE08575D41475450740F9A25414E45FF7F04575D41A1456FEB1E9A2541FA82A3D100575D4114BC7BB5529A2541DA12D42E00575D411A095C9FF29B2541'),
(43720, 860, 39668, 1, '010500000001000000010200000005000000DA62F82B2D585D416B47B963F5A025414A91A4A848585D41DBF3D3ACE8A02541EBC6CC4C52585D415587045DF5A02541F494B53456585D419B2D157A0AA12541627663D75A585D4139B6EB9F3CA12541'),
(43722, 37263, 41334, 1, '010500000001000000010200000003000000DA12D42E00575D411A095C9FF29B25417E3F05ED3E575D41AE1F0CD0F49B2541222D65396E575D41C70381E1DC9B2541'),
(43724, 37653, 48344, 1, '010500000001000000010200000002000000F48E801B7A575D41A2655836E39925414269057842575D417EBC077FF5992541'),
(43726, 10871, 48344, 1, '0105000000010000000102000000020000007D205F1E41575D41195F7C17409825414269057842575D417EBC077FF5992541'),
(43730, 15683, 55040, 1, '010500000001000000010200000004000000981A104011575D41688F813EC5A325417228463916575D419EA9A9BD64A425410E31189218575D412A6084DFEEA42541EE07D0F919575D413FCD069CE6A52541'),
(43732, 75308, 55041, 1, '010500000001000000010200000005000000DABDD22A19575D41BCC43DC78BAA254131E6819456575D41CDCABBA47FAA25412CB816A07D575D415AA5D8397FAA25410640A1699A575D41CE71A18A79AA2541EF2FE13AF5575D41B982815260AA2541'),
(43734, 72321, 56012, 1, '010500000001000000010200000002000000E53D393B9B585D41B068AD2366A725414641F2E754585D419B7FD19682A72541'),
(43736, 43444, 56012, 1, '010500000001000000010200000005000000C428B4715F585D4127795D4E73A525410CB1EBD860585D4161C00F0B6BA62541C01F9CD05F585D41BE7C897CBBA6254123DE35505C585D41E809369829A725414641F2E754585D419B7FD19682A72541'),
(43738, 31906, 56012, 1, '01050000000100000001020000000400000055D3C501FB575D4151CBA9E626A72541CC674E6231585D41D760E62C1CA72541409E448C3F585D41369C7A8F36A725414641F2E754585D419B7FD19682A72541'),
(43740, 55040, 60251, 1, '010500000001000000010200000002000000EE07D0F919575D413FCD069CE6A5254146A3729573575D41AE46C17EE3A52541'),
(43742, 5392, 60251, 1, '0105000000010000000102000000020000003CA306F299575D41551A20A0D4A5254146A3729573575D41AE46C17EE3A52541'),
(43752, 32238, 67891, 1, '010500000001000000010200000009000000ABB306D609575D416113183C27972541575AB8E90E575D41A3C7146EB79825417C6A83680E575D412B9C004CE39825414D693B320D575D414AB1846BF99825419B0A9EAE0A575D41AD90848108992541814BD698E5565D41C6CB8F211799254152C70B4ADF565D41DEDA678E35992541AA818919DE565D41E5DF33F85299254164B180E5E0565D412C71CBB97A9E2541'),
(43754, 38708, 72735, 1, '0105000000010000000102000000020000000B9F4AC051585D41E022893952A42541772F0FF69B585D4121F8379943A42541'),
(43758, 15683, 73188, 1, '010500000001000000010200000004000000981A104011575D41688F813EC5A32541EF02CDD003575D4160C84BE6C7A3254186B74D67F6565D41D5FC6AD8D1A32541285669AFCD565D41CB246BD722A42541'),
(43764, 26765, 74349, 1, '01050000000100000001020000000500000093AA82C975575D4135DD548662A125416619C75B58575D4146EA505668A12541846B85BD05575D4123B1EE7B5BA1254196BF853BF3565D41713150BB6DA12541BE242DF2E3565D419C1A2FA386A12541'),
(43766, 72489, 74409, 1, '010500000001000000010200000002000000BDC939E53C585D4164C3A1F7FA9E2541E36F6E2210585D415F4BD2160B9F2541'),
(43768, 8175, 74409, 1, '010500000001000000010200000004000000CEC48C3604585D419D31155AEA9C2541A6664AD20D585D4177B461FFBB9D254111A2E6FC0F585D41C0E158CF0B9E2541E36F6E2210585D415F4BD2160B9F2541'),
(43772, 37174, 75308, 1, '010500000001000000010200000002000000BC09BFD51B575D41E0486BEF0FA92541DABDD22A19575D41BCC43DC78BAA2541'),
(75722, 46425, 13526, 1, '010500000001000000010200000006000000837FBA50C4595D41E267BC3829A02541D7ACDE8DB6595D415956C50C92A02541BD6FCE6EA9595D41794EAEC0FAA025417057F2D4A3595D411DB75BEA2EA12541CBAB3D68A1595D4186FEC3285BA125415AA9A48AA1595D41DFD65CE686A12541'),
(75726, 46425, 20870, 1, '010500000001000000010200000008000000837FBA50C4595D41E267BC3829A02541EFD887CBD1595D41AFA43A2935A02541E96B7566DD595D414FBEE30E50A025414CC7E443E7595D414FAB4AA7A5A0254185F13DD1EE595D41107066F14BA12541B4E53A87F5595D413C0150BFB0A125415AFAC7A70F5A5D4194E197AE5AA22541A8003269165A5D4170812111CEA22541'),
(75728, 8278, 20870, 1, '010500000001000000010200000004000000C0531FD0425A5D4105D9D85649A22541AE69411A3A5A5D41EE7D134A9BA22541AAF17469345A5D415B205D4AB2A22541A8003269165A5D4170812111CEA22541'),
(75730, 33950, 22534, 1, '0105000000010000000102000000020000003055908953585D41DF45FC7705A92541DB72458C54585D41EA34E6854DAA2541'),
(75732, 22646, 22534, 1, '01050000000100000001020000000D0000009F0FEA09FF595D41E81DEEEDB7A925410C746C7EDC595D410B9FD7B7BEA9254176276218A6595D410A86221EC2A925412727337885595D41AB3FA288C8A925416DE629F669595D411D45D0F1CDA92541D2F0F60A4A595D41DA70AA1BEAA92541567CEB3D2F595D41E7CE0F4405AA25418C64498919595D41795F922018AA2541A0DEE33003595D4115EE821D2BAA25411DF99CB4E7585D410BA260D237AA2541CD7EAF70C6585D410B9C985F3EAA2541D6081018A7585D417915748C44AA2541DB72458C54585D41EA34E6854DAA2541'),
(75734, 23765, 22646, 1, '010500000001000000010200000005000000F7EED850E2595D41AF48B557C0A525412E89A381F4595D41D516B7D7E7A625415D2B1920FC595D417118B200A4A7254107AE6CEBFD595D41369F816C4BA825419F0FEA09FF595D41E81DEEEDB7A92541'),
(75736, 75907, 23765, 1, '0105000000010000000102000000020000007BDB6889055A5D41BF044A78F4A42541F7EED850E2595D41AF48B557C0A52541'),
(75740, 75907, 28324, 1, '0105000000010000000102000000040000007BDB6889055A5D41BF044A78F4A42541A295F6830E5A5D41C6601600FAA42541DEDB91151C5A5D4133F80C1A23A52541DE5209C62B5A5D412D12FF6F8DA52541'),
(75742, 20870, 28457, 1, '010500000001000000010200000005000000A8003269165A5D4170812111CEA22541311D79E8125A5D4125942F2C3CA32541A728E19B0E5A5D41388E8C5F77A32541E51BAE09025A5D41DBC2C2C9C2A325412F422A46F7595D4103872760E9A32541'),
(75744, 13526, 28457, 1, '01050000000100000001020000000C0000005AA9A48AA1595D41DFD65CE686A125412466DDEEA2595D415ACE4919ABA1254186F220F1A4595D41361ABFE1C7A12541C8A7F042AA595D41E259887C08A22541D45DFF50B5595D415ECD46AB40A225415CDE7379BE595D410DFFEB8480A225413631C4D8CF595D415C1AB3D26DA32541D8278C2AD5595D412F40946DAEA325410DB4B005DD595D41D258733DE7A325414F456620E4595D411A4332BAFBA32541DCE7F71AED595D417924E04101A425412F422A46F7595D4103872760E9A32541'),
(75746, 51217, 28520, 1, '010500000001000000010200000002000000A6244826C8585D41068D61E809A1254128B472ECDD585D417DB0F7E90CA12541'),
(75750, 56012, 33950, 1, '0105000000010000000102000000030000004641F2E754585D419B7FD19682A72541A405D24452585D4132B4DD7839A825413055908953585D41DF45FC7705A92541'),
(75752, 39221, 33950, 1, '0105000000010000000102000000020000005E6CFEFB37585D4192A0F84FFCA825413055908953585D41DF45FC7705A92541'),
(75758, 52625, 51217, 1, '0105000000010000000102000000040000003EF84E3CCC585D413B132D8EB99F25416B64E02BC9585D41A5DA0BEDE59F2541D2DFC706C8585D412C4A25EB11A02541A6244826C8585D41068D61E809A12541'),
(75764, 70733, 52625, 1, '010500000001000000010200000005000000D3473EF6F9585D4197B02122439F25410CEB6730ED585D41BDDB55F14C9F25413BEB57F4D6585D414DBDFB61849F254128739043D1585D4103E111639B9F25413EF84E3CCC585D413B132D8EB99F2541'),
(75774, 44829, 65599, 1, '010500000001000000010200000004000000C30C637658585D416A32C13C17A325416F4A97628A585D41113A2EB114A32541D81A502A90585D414605FDD81AA32541E4E0F9B594585D41331AE1D52FA32541'),
(75780, 65599, 72735, 1, '010500000001000000010200000005000000E4E0F9B594585D41331AE1D52FA32541B525214D99585D4130894E6753A32541A27DED5A9B585D41244215C47EA325413329B2CA9C585D419FF2648BB1A32541772F0FF69B585D4121F8379943A42541'),
(75784, 70733, 75242, 1, '010500000001000000010200000004000000D3473EF6F9585D4197B02122439F2541FACEED9305595D4101CFB59031A0254109D72F1709595D41125834FF96A0254106BB5C440B595D413FE94F59BAA12541'),
(75786, 28457, 75907, 1, '0105000000010000000102000000020000002F422A46F7595D4103872760E9A325417BDB6889055A5D41BF044A78F4A42541'),
(75823, 5541, 43444, 1, '010500000001000000010200000007000000A621B57E3B585D41C3D04B6182A42541BE16BB4A3C585D419DF5D848B5A4254146A952133F585D412FB34FAEFDA425418A7DFBB543585D412FB81CD42FA525413293AF9449585D417C50D02453A5254156DB2EB550585D413735B0EA6EA52541C428B4715F585D4127795D4E73A52541'),
(75889, 7303, 36118, 1, '01050000000100000001020000000200000042ACE5A5BE575D41ECFD030ED5AF2541DB21C6B4EC575D416AD403F7CBAF2541'),
(75919, 64813, 58471, 1, '010500000001000000010200000002000000A5F28F94C5575D414611AE2D43AD2541A80D36DAD6575D413EEF00C53FAD2541'),
(75921, 58868, 58471, 1, '0105000000010000000102000000020000002984B2D0F6575D41ADE6FB2A32AD2541A80D36DAD6575D413EEF00C53FAD2541'),
(75932, 58471, 72609, 1, '010500000001000000010200000002000000A80D36DAD6575D413EEF00C53FAD2541024E1A5CD6575D41F175E52C3FAE2541'),
(89377, 70107, 49762, 1, '01050000000100000001020000000B000000B8D91D6E9C585D415ACA78011F912541A3FC757981585D41EC04196147912541D935154262585D412C785F4C799125416D9ACC8C40585D41E684FB97C19125413C7A59EE2A585D411A46939FF1912541BEC7A95515585D4143F49CF128922541026DD5A2F5575D41269C5A068E922541A49FA8A6DB575D41FD7A1B64E392254142ECD4D5AA575D41E74B3FEA7E93254116B236476F575D417BDEBB54489425412F3777AD48575D41DC3F038DDA942541'),
(91046, 54304, 20514, 1, '010500000001000000010200000007000000D46D84A24E595D417842C4E36DA825417C889DD55A595D41ED5D13147AA8254175C825C575595D412510BFA98AA8254196834632A8595D4185A402465CA825416934C5D4CA595D41973174A472A82541357AB296D0595D41C58DBA8271A82541A7BD1E5CD4595D41E42FC8E25AA82541'),
(91048, 1573, 20514, 1, '0105000000010000000102000000060000000F62D628C2595D41210C0BD95FA625415E9FA7BECA595D4103BEBCB1B5A625416A0C0B35D2595D41E55BB7D23EA72541C9E610CFD5595D410614966AC1A7254191739DB7D6595D4145909CC518A82541A7BD1E5CD4595D41E42FC8E25AA82541'),
(91056, 27628, 31330, 1, '0105000000010000000102000000060000000FA0C8E748595D4174172CF396A325411A3E777B44595D41FF9638F379A42541FB2D3D3944595D41C610F801F6A4254180D421E149595D412E888CF6A3A5254184F1EF3C4A595D41370ECF9A18A625411571152C48595D41AFC0917DB9A62541'),
(91058, 1573, 31330, 1, '0105000000010000000102000000040000000F62D628C2595D41210C0BD95FA62541969C13CDB6595D41619E712495A6254197A379E9AD595D4137C606C6ACA625411571152C48595D41AFC0917DB9A62541'),
(91092, 39908, 75438, 1, '010500000001000000010200000003000000F8232D138E595D41751184C472A4254163F6F04E7B595D41AFDAE20D01A52541755B6A0277595D41659882413CA52541'),
(93066, 28324, 4055, 1, '010500000001000000010200000003000000DE5209C62B5A5D412D12FF6F8DA52541775F5E83225A5D4187088EACFCA525418412BFEB1E5A5D41AB7A879E4DA62541'),
(93068, 19179, 4055, 1, '010500000001000000010200000002000000170294740F5A5D41407F572F2CA625418412BFEB1E5A5D41AB7A879E4DA62541'),
(93077, 70733, 15914, 1, '010500000001000000010200000006000000D3473EF6F9585D4197B02122439F25418F2691623C595D4167C22A96119F25418F65B5754A595D41C5C32DD10E9F2541991BD73D59595D41B7C8D7CA219F2541EBD8DE7E67595D41742B2358599F2541ACB1676976595D411372900F989F2541'),
(93079, 51263, 16405, 1, '0105000000010000000102000000080000006DDCBB125F5A5D41958861607BA62541C442EF00605A5D41F1D1B805DAA625415B1355C1605A5D41DE87E958FEA62541F12F8025625A5D41BEDFF28B22A72541BF74B020685A5D41297C42516AA725411C34A0286A5A5D41390926648EA7254156D8BEEE6A5A5D41AF9C9C01BAA72541385A8B1C6B5A5D41FFFDC353F4A72541'),
(93083, 13078, 23765, 1, '0105000000010000000102000000080000008F8280C419595D412B03161742A2254141912E1D30595D41516A591A2FA2254164E43F074B595D41C3764B6538A2254176B5A4CF62595D4153A86A3058A2254192056B6779595D415AAE406595A22541ECA280DD8C595D412EFC201AE9A22541F6DEFE23A5595D410389BC47A9A32541F7EED850E2595D41AF48B557C0A52541'),
(93085, 16405, 26483, 1, '010500000001000000010200000007000000385A8B1C6B5A5D41FFFDC353F4A725412D915106685A5D41396BDF6719A82541716D9946645A5D410B33DE5137A82541D91EE4335F5A5D4181C2A3E746A825413678BB71325A5D41E65824FD56A8254129BBD84D2D5A5D41D22435B450A82541BF5F0B66295A5D41AEB768963BA82541'),
(93087, 4055, 26483, 1, '0105000000010000000102000000070000008412BFEB1E5A5D41AB7A879E4DA6254171B72B451D5A5D413F2C437AA5A6254152BE524A1E5A5D418426A74821A725412D163E46215A5D41A5FC114BABA7254121B2D56A235A5D4108C93ED1F3A7254190238E16265A5D4157F1E8C317A82541BF5F0B66295A5D41AEB768963BA82541'),
(93091, 44230, 28324, 1, '010500000001000000010200000005000000DA5A7E1E575A5D41900114DD51A5254186767FC54C5A5D41BB28446C2FA5254122742189425A5D417EAED66E31A525415B4A201C375A5D412CECDADA50A52541DE5209C62B5A5D412D12FF6F8DA52541'),
(93097, 10252, 44230, 1, '010500000001000000010200000002000000114316D8685A5D41CE9EA87C40A42541DA5A7E1E575A5D41900114DD51A52541'),
(93105, 15914, 46425, 1, '010500000001000000010200000009000000ACB1676976595D411372900F989F25418A38F0D97F595D41EB4D8424639F2541E0A7CCA48F595D411643E4621E9F254196A066BB9B595D41EFD82E20069F2541A4FCD8ACA6595D41609B87DB199F2541E9ACEE67B0595D414F981EB6439F2541C05EE59BB9595D412A1A4624929F2541D5123A97BF595D415AA62BE9D99F2541837FBA50C4595D41E267BC3829A02541'),
(93109, 44230, 51263, 1, '010500000001000000010200000005000000DA5A7E1E575A5D41900114DD51A5254194C77A6A5C5A5D410C42FA2D8BA5254111936C725E5A5D41A3EDDA40AFA52541975D5F275F5A5D4188A481FFC4A525416DDCBB125F5A5D41958861607BA62541'),
(93111, 43498, 51263, 1, '01050000000100000001020000000200000038041B0D7D5A5D4140D6345058A625416DDCBB125F5A5D41958861607BA62541'),
(93118, 16405, 64640, 1, '010500000001000000010200000002000000385A8B1C6B5A5D41FFFDC353F4A7254115C94F38815A5D4109B202B364A82541'),
(104257, 13916, 18194, 1, '01050000000100000001020000000A0000002B0CE26B985A5D41094F4E682D9D25412A3B4B76905A5D41759D6CAEA39D2541267174F58C5A5D41988F4BC9119E25412E80DA3F8D5A5D41D469C68E709E25415087973E915A5D41B92ACBD5A29E25413937D7559A5A5D41875E6DD1CC9E2541B9BC4147A55A5D41ECBCE08DE09E2541611181D4AE5A5D419AE94D17D09E254153674065B65A5D4126205C22AA9E2541B34A8F97BC5A5D4196A2A044679E2541'),
(94486, 11146, 45339, 1, '01050000000100000001020000000200000044A59163EA5C5D41A9AF309358A9254164F3864EEB5C5D410656760257AB2541'),
(95095, 31330, 54304, 1, '0105000000010000000102000000040000001571152C48595D41AFC0917DB9A625411AEAE7D247595D41F428426318A725415D4AE5B14B595D41CA272176F2A72541D46D84A24E595D417842C4E36DA82541'),
(99135, 66572, 9117, 1, '010500000001000000010200000009000000CE839E0D835A5D41D6BFFB61879525410107D2AE955A5D4139F47B266D962541A60A7E92A85A5D4125E675DCD6962541DEC10D35AD5A5D411385600309972541177DB1F7AF5A5D41A4E63C1F4A9725413941A489B15A5D4143CD6FA4A8972541B2DA92C8B15A5D4120095FD5F8972541835493D4AE5A5D41753CFAA649982541379440BEAB5A5D41CC99FCBA6E982541'),
(99137, 62271, 9117, 1, '0105000000010000000102000000070000008FB9F1495C5A5D41107CD24F86972541A8EAE2247A5A5D4139DDE50B0B982541B9ABD031895A5D411DE7888275982541449E1258905A5D413ABA4A949898254161844BCD9D5A5D4159EB9A3B9D982541974E37D1A45A5D412DE4D18F94982541379440BEAB5A5D41CC99FCBA6E982541'),
(99139, 74659, 10396, 1, '010500000001000000010200000003000000BFE6DBC6275A5D417AC411D221992541041B3D1E395A5D41C7095E4C34992541739C29A1485A5D413572545064992541'),
(99141, 62271, 10396, 1, '0105000000010000000102000000020000008FB9F1495C5A5D41107CD24F86972541739C29A1485A5D413572545064992541'),
(99159, 10396, 41528, 1, '010500000001000000010200000002000000739C29A1485A5D41357254506499254157DDB4AC675A5D41EDE5CEA2CB992541'),
(99179, 66572, 58219, 1, '010500000001000000010200000007000000CE839E0D835A5D41D6BFFB61879525410C4CDC606E5A5D41258356CA499525418EC8B87A635A5D411B7BA9A2449525419ABAA5124F5A5D41F9D475865E9525410A74DE45305A5D41609F36654795254156F7A276255A5D4110A4DD665F952541CB0F74380A5A5D4135C57A49BC952541'),
(99185, 24144, 62271, 1, '010500000001000000010200000005000000D13EEFA6175A5D410A5E456F599725418FB9DB7B225A5D41B0DAD2B748972541B4F6CFA32E5A5D41E3859E5446972541C01E53BD455A5D41E35F81AD579725418FB9F1495C5A5D41107CD24F86972541'),
(99187, 24984, 66572, 1, '0105000000010000000102000000060000008B78D87BAC5A5D4180A0FD304C9525414D7C1FCCA25A5D419FFAF8E9309525419F1D3242975A5D414DF935E22B95254112ABA8F68E5A5D41737551CE349525418E9583E9895A5D41E64143AE4B952541CE839E0D835A5D41D6BFFB6187952541'),
(99201, 14902, 6851, 1, '010500000001000000010200000006000000B61E5F07B3585D412DBBF560BB992541F338E36AB7585D417DF911569D992541F04E58B6BF585D41518D69689499254173CCD962E0585D41EEF1E18F9C992541BA7F2336E6585D413459694CB19925419494333EE8585D41F4EBF95ED5992541'),
(99209, 5717, 11736, 1, '0105000000010000000102000000020000008A156D7DE7585D41894669D5509B25411448CDD103595D4139CEAC9C859B2541'),
(99303, 66810, 43444, 1, '010500000001000000010200000004000000BFE00D7B99585D41E32F07832DA525416BB2587F94585D419059C7425AA52541333305968B585D41445C1E9B6AA52541C428B4715F585D4127795D4E73A52541'),
(99327, 72735, 66810, 1, '010500000001000000010200000003000000772F0FF69B585D4121F8379943A425410740F47F9C585D41F49A908FF2A42541BFE00D7B99585D41E32F07832DA52541'),
(99810, 45715, 14275, 1, '010500000001000000010200000004000000AE9DD26A53595D418043A7941A962541C3B1546F6D595D41A12FE20EA09625417823E52070595D410C3A9A4BCB9625411A01C60371595D4146BA495C1B972541'),
(99822, 30525, 18596, 1, '0105000000010000000102000000020000006697657D3F595D41404D85E5409925410949C204AB595D41464214563A992541'),
(99831, 55231, 30525, 1, '0105000000010000000102000000030000009587AD7B47595D41E7AE02A905982541AF36794C40595D410C53878DA79825416697657D3F595D41404D85E540992541'),
(99847, 62262, 45715, 1, '010500000001000000010200000005000000BBB4CDB46D595D41170C98C057952541C93A7EA961595D417B440B987E95254140D6CF095C595D4184119A77AB952541D064F9AB57595D41DF2F77CCD0952541AE9DD26A53595D418043A7941A962541'),
(99849, 46463, 48062, 1, '010500000001000000010200000004000000EA3CA2A927595D41ACCFBCBC72972541822322C31D595D41C8FB711AE2972541E97EE07D1E595D4168FE4223FF9725419694EDD01F595D413DF250770D982541'),
(99873, 44943, 69693, 1, '0105000000010000000102000000050000005C03BC3BFF595D41CD93FC15AD992541CCF8D7B30B5A5D41F8F254C2109A25419CB5C212165A5D4195CA217D3A9A25415975B4BC1F5A5D41E31159794E9A254141E66B9A3E5A5D41581432797B9A2541'),
(99875, 10396, 69693, 1, '010500000001000000010200000002000000739C29A1485A5D41357254506499254141E66B9A3E5A5D41581432797B9A2541'),
(99979, 55231, 30924, 1, '0105000000010000000102000000030000009587AD7B47595D41E7AE02A905982541489C3A494D595D41B34B831B13982541935F6E6B59595D412B95046D09982541'),
(99999, 36049, 45715, 1, '010500000001000000010200000002000000ED76A4BB3C595D4128832037C0952541AE9DD26A53595D418043A7941A962541'),
(100001, 36049, 46463, 1, '010500000001000000010200000007000000ED76A4BB3C595D4128832037C0952541BB858BF936595D41FE813059C1952541375E3D9032595D414B6D9719D89525414C608D6321595D41775ECC32CC962541DE85ADED20595D41283D23A5069725410141BDAA23595D41732B4D7640972541EA3CA2A927595D41ACCFBCBC72972541'),
(100856, 6810, 6395, 1, '0105000000010000000102000000040000004C05189BEA5C5D411C439CCD14AC2541C994EF0AE95C5D41F64EFED189AC25416C2541FDE15C5D419D589C7157AD25415AC2401EDA5C5D4155A009DFEAAD2541'),
(100858, 6834, 11395, 1, '01050000000100000001020000000400000006750647945C5D413D1E472E8DAA254161F44E14B85C5D41D7159CE37EAA25417F65D83DBD5C5D413C2C25788CAA254153D04FC9C15C5D418064F776A1AA2541'),
(100870, 66776, 24628, 1, '010500000001000000010200000009000000708B6AEB375C5D419D08978A22AB2541E05DE909315C5D41C0FAE6F256AB2541E4FF0D90295C5D415BEFD10F9AAB25412590F4721E5C5D4161D178891FAC254134486B001C5C5D414740027D44AC2541BBEE9693195C5D419977D2BA70AC254147E42C5D185C5D417ED1BAD986AC2541D143D16E155C5D41DA143CF5DEAC254132B59482145C5D414B26B5D953AD2541'),
(100873, 32198, 25021, 1, '01050000000100000001020000000A000000A581B33B725B5D41F36C8DD088AE25412FCB04B6A65B5D41FCE364D485AE2541548AECD7BB5B5D41161E63FC88AE2541D25FFA57C05B5D41D62433668FAE2541039A4425C65B5D419F862ADA9CAE25414888079CCC5B5D412F775B78B1AE2541B0B4D683D95B5D410CFC836AD3AE2541035E96CDE55B5D4152D811C7FCAE2541594C4186F65B5D419150C5AE16AF25410627ABFE0A5C5D41B24734AD12AF2541'),
(100875, 58520, 28437, 1, '0105000000010000000102000000050000006146E653205C5D41042E827257AF25418B7D209C305C5D4144931B17B3AF2541987403E8475C5D41101D301106B02541CF5B5344505C5D41B39D590513B0254100F7B1AD665C5D41EC7EB7EE15B02541'),
(100877, 53024, 28437, 1, '0105000000010000000102000000040000003E2E4C57B75C5D41ED5BE98148AF254184B7DFEE9A5C5D41283FE210CAAF25414EB584CD825C5D41A4B5942309B0254100F7B1AD665C5D41EC7EB7EE15B02541'),
(100879, 24628, 28437, 1, '01050000000100000001020000000800000032B59482145C5D414B26B5D953AD25410477B017325C5D411044C71F81AD25413E2DAB9F415C5D41659D2571B8AD254112486DF5535C5D41A78885733FAE254139993BFA5D5C5D41ACD65816C8AE2541CEE0B4BE625C5D41C021C0FB25AF2541F03BE397655C5D411DC03B4184AF254100F7B1AD665C5D41EC7EB7EE15B02541'),
(100884, 6834, 35357, 1, '01050000000100000001020000000500000006750647945C5D413D1E472E8DAA2541A034B14B955C5D41F107F0FC08AB254153D86CC4945C5D414BBD52902DAB2541288C39EA925C5D4153CA2ECF43AB2541860E64B78F5C5D41F08B3E6F44AB2541'),
(100886, 23508, 41613, 1, '01050000000100000001020000000200000058005DDAC55C5D411F63B427BDAB2541E44CC814E05C5D41C9DAE107B8AB2541'),
(100890, 23508, 45197, 1, '01050000000100000001020000000700000058005DDAC55C5D411F63B427BDAB2541F4E042CCC15C5D41983AEF8A48AC25413404A62EBE5C5D419333B13192AC254190970BA0B85C5D4154B92FEED4AC25415DADFB67B25C5D41B3F36B8010AD254173023A2AAC5C5D41E8AB65C844AD25416E94659A955C5D411A737B60E2AD2541'),
(100902, 24628, 52723, 1, '01050000000100000001020000000300000032B59482145C5D414B26B5D953AD25412251D114135C5D41C82FDF9BF4AD2541ADD4E0AE135C5D41872F4771B9AE2541'),
(100904, 45197, 53024, 1, '0105000000010000000102000000040000006E94659A955C5D411A737B60E2AD2541871682F19A5C5D4119F826472AAE25413D69D3409E5C5D41AE887B1A4EAE25413E2E4C57B75C5D41ED5BE98148AF2541'),
(100906, 6395, 53024, 1, '0105000000010000000102000000040000005AC2401EDA5C5D4155A009DFEAAD25412AEAFC62CE5C5D41947831C277AE254139FDB634C35C5D416D3B4D5CE7AE25413E2E4C57B75C5D41ED5BE98148AF2541'),
(100915, 50250, 68455, 1, '01050000000100000001020000000200000033B81F89295D5D410D802714CCAE2541B294350F225D5D41A79F57300FAF2541'),
(100917, 6395, 68455, 1, '0105000000010000000102000000030000005AC2401EDA5C5D4155A009DFEAAD254157B758E91A5D5D41562DB31CECAE2541B294350F225D5D41A79F57300FAF2541'),
(100919, 2217, 72610, 1, '010500000001000000010200000003000000DE0AAB5D115D5D41F794F01AD0AF2541844B5E0D215D5D41B833A0753AB0254113F63FB5255D5D41431004E873B02541'),
(100921, 14331, 72627, 1, '010500000001000000010200000002000000F4BB7AAFF45C5D41CA81DDC5DFAB25415F9DF1A9245D5D41688C4967D6AB2541'),
(100923, 11991, 72627, 1, '0105000000010000000102000000020000004DC271F9235D5D4185C2B968F4AA25415F9DF1A9245D5D41688C4967D6AB2541'),
(100872, 52723, 25021, 1, '010500000001000000010200000005000000ADD4E0AE135C5D41872F4771B9AE254178597987105C5D41CFB20CA6C8AE2541B02D8A090E5C5D41C7C40D05DFAE2541770150910B5C5D4192B755AEFCAE25410627ABFE0A5C5D41B24734AD12AF2541'),
(100908, 52723, 58520, 1, '010500000001000000010200000005000000ADD4E0AE135C5D41872F4771B9AE25412C8C276D1B5C5D41B74E95CFCDAE25415A3D16B11E5C5D4136A3320EE3AE25418A593179215C5D418E7EC7742BAF25416146E653205C5D41042E827257AF2541'),
(100931, 45339, 14331, 1, '01050000000100000001020000000500000064F3864EEB5C5D410656760257AB25410442FACAF15C5D41B2A4ADEB72AB25419CC08576F45C5D415C681BDF96AB25416A541231F55C5D41A12339E8B3AB2541F4BB7AAFF45C5D41CA81DDC5DFAB2541'),
(102010, 72489, 66204, 1, '010500000001000000010200000002000000BDC939E53C585D4164C3A1F7FA9E2541D4CD77803D585D41F28BB8CCBF9F2541'),
(102014, 47085, 72489, 1, '010500000001000000010200000002000000E2B0B3C83B585D41E7216A00629E2541BDC939E53C585D4164C3A1F7FA9E2541'),
(104189, 37174, 21350, 1, '010500000001000000010200000005000000BC09BFD51B575D41E0486BEF0FA9254182FE60B5F6565D4117E7B0FA0FA92541C4287455F0565D414665B88818A92541841E98AAEA565D4195B22BD536A92541C57CAEA8D3565D4113932EAD42A92541'),
(104253, 32083, 13916, 1, '0105000000010000000102000000020000007483E21C815A5D41DF9B5BE8069C25412B0CE26B985A5D41094F4E682D9D2541'),
(104255, 45162, 18194, 1, '01050000000100000001020000000300000057AD2C64BE5A5D41DF70FDE66E9D2541AFB94F2FC05A5D4190E0E452169E2541B34A8F97BC5A5D4196A2A044679E2541'),
(104261, 69693, 32083, 1, '01050000000100000001020000000500000041E66B9A3E5A5D41581432797B9A2541C42738CF595A5D4102E47C8CE39A2541566C7F126A5A5D418CD5D5E3379B254172053C90765A5D41FBCBFADAA29B25417483E21C815A5D41DF9B5BE8069C2541'),
(104263, 52, 32083, 1, '0105000000010000000102000000050000004A5B2AC6BC5A5D418AAAD2798E9A2541BD69FB3FA35A5D41F25CFF5DA99A25415485188F9D5A5D4110230B5EC09A2541ABD060EF975A5D41CC5DE73CED9A25417483E21C815A5D41DF9B5BE8069C2541'),
(104265, 41133, 32198, 1, '0105000000010000000102000000020000000AA3ACE8705B5D41F4F6CFD493A92541A581B33B725B5D41F36C8DD088AE2541'),
(104285, 13916, 45162, 1, '0105000000010000000102000000030000002B0CE26B985A5D41094F4E682D9D2541FFC5E79DA85A5D41A64342E16B9D254157AD2C64BE5A5D41DF70FDE66E9D2541'),
(104287, 52, 45162, 1, '0105000000010000000102000000020000004A5B2AC6BC5A5D418AAAD2798E9A254157AD2C64BE5A5D41DF70FDE66E9D2541'),
(105585, 3604, 6342, 1, '01050000000100000001020000000600000053B6DCB0835C5D41B5B3E11E0E892541DCCA09E38B5C5D4162EBABD4878A2541C9AE671F915C5D411679B6D17E8B254153E390CC935C5D41460DD14E768C2541F5D67080955C5D416385E791008D254159812032955C5D4157B0F30B6E8D2541'),
(105704, 72627, 62746, 1, '0105000000010000000102000000040000005F9DF1A9245D5D41688C4967D6AB254107F5E2B9255D5D41290E90CA60AC254194734AAB245D5D4189C546F1A9AC25417ACCA20D215D5D41CBB4E497F3AC2541'),
(108251, 47849, 3604, 1, '010500000001000000010200000004000000625966BB795C5D41EFE480718E872541089E25487A5C5D41B5EFF887AA87254146B874217D5C5D41830B62CD0888254153B6DCB0835C5D41B5B3E11E0E892541'),
(108273, 15237, 38826, 1, '010500000001000000010200000006000000F466FF93D55C5D41D0AC5576248725416BD51954D05C5D418C0DF94C2C872541089E25487A5C5D41B5EFF887AA8725412F388186585C5D41F7DB0831E4872541B56B84B8215C5D41C80C9ADA37882541328B7DDBE75B5D41A44EE61991882541'),
(108276, 23267, 48536, 1, '010500000001000000010200000006000000BE980C6D765D5D41DFBEE2EA88862541B3178580465D5D41CA3D0094D3862541DEE677CBD35C5D41F12437288387254146B874217D5C5D41830B62CD08882541A0BAB47B085C5D417741A080B18825417B244C35E85B5D410561082BE1882541'),
(108282, 46301, 6834, 1, '010500000001000000010200000002000000CBB247528B5C5D41AF9D74EE8EAA254106750647945C5D413D1E472E8DAA2541'),
(108305, 46301, 35357, 1, '010500000001000000010200000004000000CBB247528B5C5D41AF9D74EE8EAA2541B0CB5A628C5C5D417C47A95119AB25413E4AEC1C8D5C5D413534BF5A36AB2541860E64B78F5C5D41F08B3E6F44AB2541'),
(108318, 61399, 48062, 1, '010500000001000000010200000004000000F920E2DE2C595D414BE4ECE38E97254117956E4B24595D411379AB950C982541A3EFCF6522595D41763DA340149825419694EDD01F595D413DF250770D982541'),
(108324, 61399, 55231, 1, '010500000001000000010200000002000000F920E2DE2C595D414BE4ECE38E9725419587AD7B47595D41E7AE02A905982541'),
(108331, 46463, 61399, 1, '010500000001000000010200000002000000EA3CA2A927595D41ACCFBCBC72972541F920E2DE2C595D414BE4ECE38E972541'),
(108902, 58688, 2882, 1, '010500000001000000010200000003000000166B9AB7AE575D41217DA051C3A32541938BCE19B8575D41B5D003104CA42541EE5CA0E9BF575D41AB70AD4976A42541'),
(108904, 67042, 5541, 1, '010500000001000000010200000004000000D61EFEE4F8575D41ED59ECA179A42541F27D03F806585D41488421DB76A42541A50F328D12585D41EAE26B748AA42541A621B57E3B585D41C3D04B6182A42541'),
(108912, 61113, 15420, 1, '01050000000100000001020000000400000024FD63C6F1575D410ADF770952A025411C7437E4ED575D41A334D23644A02541F5291845BD575D41ABF619CF4DA02541E76E2338B8575D413F117FB064A02541'),
(108926, 67042, 31906, 1, '010500000001000000010200000002000000D61EFEE4F8575D41ED59ECA179A4254155D3C501FB575D4151CBA9E626A72541'),
(108968, 2882, 67042, 1, '010500000001000000010200000003000000EE5CA0E9BF575D41AB70AD4976A4254125F6BD8DC9575D41859F58F982A42541D61EFEE4F8575D41ED59ECA179A42541'),
(109062, 2791, 12545, 1, '01050000000100000001020000000300000056AAB479E0575D41EE5BC68D99A7254183087A96E0575D41E0681701BEA725411CF6F365DF575D41684AC76ADBA72541'),
(109119, 12545, 55041, 1, '0105000000010000000102000000030000001CF6F365DF575D41684AC76ADBA725411F3A7C43F4575D41386828D926A92541EF2FE13AF5575D41B982815260AA2541'),
(113486, 17855, 2145, 1, '0105000000010000000102000000060000000E08780EEF5C5D414F2C425EABA4254161166174E95C5D41C5241586DFA4254127DA62F7E95C5D41EF26653287A52541130C6CCEEA5C5D415C59E0AEC8A52541AAF0E2E1025D5D418AAD46D21AA725413B44E9B8035D5D418BB5C44E5CA72541'),
(113488, 64320, 6481, 1, '0105000000010000000102000000040000008DD335CABC5C5D418E1A1943E0A52541560228A3CB5C5D416BDDC12009A6254133A14987D15C5D41AAC06EBE33A62541A26A4538E45C5D41B7B538662FA72541'),
(113490, 57573, 6706, 1, '010500000001000000010200000004000000C4A2C0671B5D5D41482A5C0871A22541924567241E5D5D4148BDA5DAAAA22541C2A5BDB21E5D5D419899821B61A325417CC930C41B5D5D410288B036B9A32541'),
(113494, 2145, 13659, 1, '0105000000010000000102000000030000003B44E9B8035D5D418BB5C44E5CA7254184D8F7D9045D5D4199CDD690FCA72541B19073D8085D5D4170F4DED82EA82541'),
(113500, 41434, 17855, 1, '0105000000010000000102000000020000003986B1741C5D5D4107A034359BA425410E08780EEF5C5D414F2C425EABA42541'),
(113510, 23536, 31681, 1, '010500000001000000010200000004000000009E7D59055B5D415037904B05A325416EB3A8B00D5B5D414910EF477EA5254172CF1280135B5D4104A06F455FA625413BE0D4D5135B5D41F55C7E9FCCA62541'),
(113512, 64789, 40295, 1, '010500000001000000010200000005000000C687958F1B5B5D4167850D4253A02541C6530B32205B5D415F81316985A025417E8CBCDD225B5D41A85A1E5CA9A025419C4DE5CA375B5D41F1ED27B00AA2254115BF7CA63C5B5D4123240DBE85A22541'),
(113514, 6706, 41434, 1, '0105000000010000000102000000020000007CC930C41B5D5D410288B036B9A325413986B1741C5D5D4107A034359BA42541'),
(113516, 41434, 43214, 1, '0105000000010000000102000000030000003986B1741C5D5D4107A034359BA4254128AB9EB21F5D5D4110706B07F0A725414479C7651B5D5D41C5F775392BA82541'),
(113518, 13659, 43214, 1, '010500000001000000010200000002000000B19073D8085D5D4170F4DED82EA825414479C7651B5D5D41C5F775392BA82541'),
(113533, 6481, 51789, 1, '010500000001000000010200000005000000A26A4538E45C5D41B7B538662FA72541D65C3309E85C5D414D79005C27A7254137DF37EBEB5C5D41F5CE9C3035A72541351CDB34EF5C5D41C678C4B951A7254106C5B6E9EF5C5D419F949A7867A72541'),
(113534, 2145, 51789, 1, '0105000000010000000102000000020000003B44E9B8035D5D418BB5C44E5CA7254106C5B6E9EF5C5D419F949A7867A72541'),
(113544, 1260, 64320, 1, '01050000000100000001020000000300000061A30645905C5D413B5DEBF46CA52541805BB08E935C5D413A18F47D89A525418DD335CABC5C5D418E1A1943E0A52541'),
(113532, 51789, 50466, 1, '01050000000100000001020000000400000006C5B6E9EF5C5D419F949A7867A72541ADF2B95CEF5C5D418428B1C184A725412050BBDEEC5C5D4131D778209BA725418BC7086AE85C5D41AAB4AC4AA3A72541'),
(113565, 40295, 23536, 1, '01050000000100000001020000000200000015BF7CA63C5B5D4123240DBE85A22541009E7D59055B5D415037904B05A32541'),
(113567, 33979, 23536, 1, '010500000001000000010200000002000000F89B2725FF5A5D410C48319F74A22541009E7D59055B5D415037904B05A32541'),
(113571, 66852, 31681, 1, '0105000000010000000102000000020000004F91ABEFE15A5D41986D7D68D6A625413BE0D4D5135B5D41F55C7E9FCCA62541'),
(113573, 58488, 31425, 1, '0105000000010000000102000000020000009DE48903475B5D41E59E4A97C2A62541062AD9566F5B5D41D18BD5FBC1A62541'),
(113599, 40295, 58488, 1, '01050000000100000001020000000400000015BF7CA63C5B5D4123240DBE85A225411743B664425B5D411549D5DC50A3254166FFE359465B5D41AB178B1948A425419DE48903475B5D41E59E4A97C2A62541'),
(113601, 31681, 58488, 1, '0105000000010000000102000000020000003BE0D4D5135B5D41F55C7E9FCCA625419DE48903475B5D41E59E4A97C2A62541'),
(145783, 9440, 22438, 1, '010500000001000000010200000005000000E51F052D7C585D419FC3F3368D9725410D48B63180585D41739362C7C6972541BBCCC5908A585D413B998E80F09725416DB319D394585D41124D76C6F5972541220C1CC89D585D41BE1CAF02F4972541'),
(118233, 66852, 32404, 1, '0105000000010000000102000000080000004F91ABEFE15A5D41986D7D68D6A62541C97B6089E35A5D41620AFDC10FA825410E04ACFEE45A5D4112CDE8D349A8254150B76E70E85A5D41453D486499A8254107305678EA5A5D41AD8A4677BDA82541A2538B27EB5A5D417F7FB2EBCBA825410583FB32EB5A5D4153083D80DAA825418963592FEB5A5D4177A4EFBFA6A92541'),
(118235, 22646, 32404, 1, '0105000000010000000102000000020000009F0FEA09FF595D41E81DEEEDB7A925418963592FEB5A5D4177A4EFBFA6A92541'),
(118240, 32404, 41133, 1, '0105000000010000000102000000020000008963592FEB5A5D4177A4EFBFA6A925410AA3ACE8705B5D41F4F6CFD493A92541'),
(124885, 6342, 63826, 1, '01050000000100000001020000000200000059812032955C5D4157B0F30B6E8D2541E4C78096C45C5D41E9CF1860738D2541'),
(125659, 64473, 59551, 1, '0105000000010000000102000000020000004783C1C9295D5D41333BD41362A9254140F7D2A7365D5D4119B65CEF65A92541'),
(125988, 71607, 30924, 1, '010500000001000000010200000002000000B1F18F165F595D41249FFA21EB972541935F6E6B59595D412B95046D09982541'),
(126006, 36984, 53057, 1, '01050000000100000001020000000300000084EFF45FA7595D41C9B851600997254127CFD9B1AC595D41DD8317FB49972541200EFB83B6595D4199EEC0FE90972541'),
(126016, 53057, 63435, 1, '010500000001000000010200000005000000200EFB83B6595D4199EEC0FE909725419B8F487BC1595D41530E7A04AC97254121F23558CE595D41AC5B685FBF97254189603F37E9595D41BEB88117BA972541F5841A6EF3595D41C59B4ECAB0972541'),
(126018, 53057, 71607, 1, '010500000001000000010200000006000000200EFB83B6595D4199EEC0FE90972541EDB11863A4595D4101E992271F9825411F1821C19C595D416F468A3E2F9825416F00A61B6C595D417E784184319825416EE8194E66595D41DFB3AE1124982541B1F18F165F595D41249FFA21EB972541'),
(126020, 14275, 71607, 1, '0105000000010000000102000000020000001A01C60371595D4146BA495C1B972541B1F18F165F595D41249FFA21EB972541'),
(126263, 6342, 7177, 1, '01050000000100000001020000000400000059812032955C5D4157B0F30B6E8D2541814AEBFA915C5D414F3B8FEB3A8E2541D429EF598D5C5D4178EC954DDC8E2541D3232A15885C5D415F32A3CF7D8F2541'),
(126267, 30110, 9440, 1, '010500000001000000010200000003000000084DA5A978585D417AA139FF87952541F73C72027A585D41CB49E8663D972541E51F052D7C585D419FC3F3368D972541'),
(126271, 52078, 11736, 1, '0105000000010000000102000000040000006045BCF119595D41052B9CEF899925412EC83C7212595D41CE6893C4C59925411934959E0D595D41A21CEB8B259A25411448CDD103595D4139CEAC9C859B2541'),
(126277, 9440, 13665, 1, '010500000001000000010200000002000000E51F052D7C585D419FC3F3368D972541ACE3801A6B585D41D6B4D93AD2972541'),
(126283, 42315, 27158, 1, '0105000000010000000102000000030000007B41623958585D41ADB107133C982541967D23A086585D4182923F22409A254187C4879F93585D41B57126397F9A2541'),
(126287, 16195, 30674, 1, '010500000001000000010200000004000000077FCB83F4585D418DD62B11189525410DCA03A5ED585D41AAE59505209625413509DFFBEA585D415DBB209DCF962541368CA54CE9585D41B7AD5D6EEC972541'),
(126293, 30364, 39668, 1, '0105000000010000000102000000040000004B0A20DCA6585D417579C02B09A1254148F3AF3C6D585D41DA44DCEF05A125417AAABF0B63585D41CE77E78816A12541627663D75A585D4139B6EB9F3CA12541'),
(126304, 71223, 42315, 1, '010500000001000000010200000009000000A95E4F020C585D419E3D27E4C1952541D6D610F624585D413AE75AF8BC9525416C2D167C29585D41BCDDC8AACA952541142EA5AB2E585D41A2982F87DF952541B25ACBE146585D4168A892D289962541500379484A585D41445978CDCA9625414E45C41F4C585D414C156BCD80972541C37554954D585D41ABF0EDDEBA9725417B41623958585D41ADB107133C982541'),
(126306, 13665, 42315, 1, '010500000001000000010200000002000000ACE3801A6B585D41D6B4D93AD29725417B41623958585D41ADB107133C982541'),
(126312, 30364, 51217, 1, '0105000000010000000102000000030000004B0A20DCA6585D417579C02B09A1254146987B60BB585D41CF57D6B713A12541A6244826C8585D41068D61E809A12541'),
(126316, 30674, 52078, 1, '010500000001000000010200000003000000368CA54CE9585D41B7AD5D6EEC9725416313881CF1585D41638CF5A8169825416045BCF119595D41052B9CEF89992541'),
(126326, 3724, 64789, 1, '010500000001000000010200000005000000B9B2029A365B5D415658F0C5B49F2541E25ABF9D285B5D41918F42B1D49F25413B918B54225B5D4196FCA665FA9F25412D1AAEF61D5B5D41FE84BDB91FA02541C687958F1B5B5D4167850D4253A02541'),
(135353, 50466, 11146, 1, '0105000000010000000102000000020000008BC7086AE85C5D41AAB4AC4AA3A7254144A59163EA5C5D41A9AF309358A92541'),
(135393, 41133, 47608, 1, '0105000000010000000102000000020000000AA3ACE8705B5D41F4F6CFD493A92541D9912A6FF35B5D4184BF089181A92541'),
(135371, 47608, 18110, 1, '010500000001000000010200000002000000D9912A6FF35B5D4184BF089181A92541F6962046275C5D41D7CC99B77EA92541'),
(136730, 51632, 9492, 1, '0105000000010000000102000000090000001471639D9C585D41FCA8C43985912541A4271D2681585D41924B0591AD9125417F8390346A585D4115481A44CF9125419FD559BF50585D41E1BB100D00922541B3E44D681B585D4120B986DE8D9225419E9E6633FE575D418BD42C93DC92254169291D7BD2575D4109FCD1CB6F932541061896F5B5575D412D5481F5CC9325419DF5C2CE58575D416EFEBB2103952541'),
(136764, 49762, 60393, 1, '0105000000010000000102000000020000002F3777AD48575D41DC3F038DDA94254164118F65C7565D4164DCFF4C85962541'),
(136765, 9492, 60441, 1, '0105000000010000000102000000020000009DF5C2CE58575D416EFEBB2103952541470D801FCC565D4100DE1E9BD4962541'),
(98919, 58219, 24144, 1, '010500000001000000010200000002000000CB0F74380A5A5D4135C57A49BC952541D13EEFA6175A5D410A5E456F59972541'),
(98953, 24144, 63435, 1, '010500000001000000010200000003000000D13EEFA6175A5D410A5E456F599725417CA60443FE595D419744B412A0972541F5841A6EF3595D41C59B4ECAB0972541'),
(98957, 63435, 63998, 1, '010500000001000000010200000002000000F5841A6EF3595D41C59B4ECAB0972541C15382C3F4595D41541258A892982541'),
(142278, 22534, 51659, 1, '010500000001000000010200000005000000DB72458C54585D41EA34E6854DAA2541BA9441E854585D418F57232AC2AA2541F028128E58585D41E355015653AB2541995627B55C585D41F6CB00A4B8AB254190F485DE62585D41B8F737BA3AAC2541'),
(142332, 22646, 35278, 1, '0105000000010000000102000000020000009F0FEA09FF595D41E81DEEEDB7A92541A637E472005A5D41374FDD3483AB2541'),
(142826, 35278, 28581, 1, '010500000001000000010200000008000000A637E472005A5D41374FDD3483AB25415B93980D015A5D413607210A48AC25411220DE55FF595D41768916078AAC2541DB8BF934F9595D415BEF1DC4E2AC25410D75F8F5ED595D4109D89F823CAD2541CD96A8D0E3595D41AD55A8AE5BAD2541CA94DCAED7595D41B1C77D5C65AD2541E4952B9A82595D41F452151776AD2541'),
(142945, 35278, 55384, 1, '010500000001000000010200000004000000A637E472005A5D41374FDD3483AB2541C2D21AD5565A5D41F091788879AB254135C838465D5A5D41BA1073DB86AB2541FCB97239615A5D41FEB6DE8DAAAB2541'),
(142966, 51659, 70832, 1, '01050000000100000001020000000500000090F485DE62585D41B8F737BA3AAC25418B2423B253585D411E03321378AC25411DBF122647585D41FD2FE5C9CAAC25413AB4253435585D4103748D4793AD2541DCCEBF6F2E585D41250EFE25ECAD2541'),
(156481, 53153, 52, 1, '010500000001000000010200000002000000F8E8E964BC5A5D41EF25478B129A25414A5B2AC6BC5A5D418AAAD2798E9A2541'),
(99199, 6851, 5717, 1, '0105000000010000000102000000070000009494333EE8585D41F4EBF95ED59925419AA77AA2E9585D41DCCCCA91F9992541111530BFE9585D41098E1B051E9A254114184508E5585D419136D83FA29A2541196BDDFFE3585D4175C13DB1F29A2541880B5E75E5585D41297ED8C22C9B25418A156D7DE7585D41894669D5509B2541'),
(145699, 10119, 15683, 1, '01050000000100000001020000000300000092B1C1F9F3565D41182AE54D5EA225418735CCCE09575D41A824E36943A32541981A104011575D41688F813EC5A32541'),
(145738, 15420, 41004, 1, '010500000001000000010200000003000000E76E2338B8575D413F117FB064A02541F8F40CC0B5575D4162FBD95A82A02541EA8D3A64B7575D4169B6F58796A22541'),
(145770, 41004, 9721, 1, '010500000001000000010200000002000000EA8D3A64B7575D4169B6F58796A225410095D5CBB7575D419B16ADC019A32541'),
(145792, 45162, 28660, 1, '01050000000100000001020000000300000057AD2C64BE5A5D41DF70FDE66E9D254143F0B162CE5A5D41FF1BC6C36B9D25418D59AE81E55A5D4183DD6468849D2541'),
(145794, 27732, 30364, 1, '01050000000100000001020000000700000055CE3DED92585D41655991977C9E2541282728D596585D41D23EBBB4919E25416C83091F9A585D41AE1B6F3CAE9E25417E7F5FD69C585D41972833C3E09E2541FCF2E44B9E585D4182E4C4D41A9F2541DDE06270A1585D41D6E78BDED79F25414B0A20DCA6585D417579C02B09A12541'),
(145796, 22438, 30674, 1, '010500000001000000010200000003000000220C1CC89D585D41BE1CAF02F4972541857FF61EDD585D4138EFDF88E7972541368CA54CE9585D41B7AD5D6EEC972541'),
(145804, 59890, 44829, 1, '0105000000010000000102000000020000000A06272657585D41555E23A93CA22541C30C637658585D416A32C13C17A32541'),
(145814, 27427, 58029, 1, '0105000000010000000102000000020000001B24E9A8E95A5D41327CE50A5DA025410E759C23E25A5D4130083A9491A02541'),
(145816, 9721, 58688, 1, '0105000000010000000102000000030000000095D5CBB7575D419B16ADC019A32541D2A7F903B3575D41B8803A1D88A32541166B9AB7AE575D41217DA051C3A32541'),
(145818, 39668, 59890, 1, '010500000001000000010200000003000000627663D75A585D4139B6EB9F3CA1254107D8E70356585D415DFFA1679CA125410A06272657585D41555E23A93CA22541'),
(145824, 27427, 64789, 1, '0105000000010000000102000000030000001B24E9A8E95A5D41327CE50A5DA02541AD7733D4F35A5D4153E4312A45A02541C687958F1B5B5D4167850D4253A02541'),
(145826, 61113, 65830, 1, '01050000000100000001020000000300000024FD63C6F1575D410ADF770952A025413C6693BFF5575D413A7A2B057DA0254190E55197F7575D417FEBAECED2A22541'),
(145828, 65830, 67042, 1, '01050000000100000001020000000200000090E55197F7575D417FEBAECED2A22541D61EFEE4F8575D41ED59ECA179A42541'),
(75718, 71244, 8278, 1, '0105000000010000000102000000020000005D7578C0345A5D4174CBCADA7FA12541C0531FD0425A5D4105D9D85649A22541'),
(75788, 44829, 5541, 1, '010500000001000000010200000005000000C30C637658585D416A32C13C17A325418D8C550344585D41973C439022A3254162E18E163D585D41F395CB6648A32541B10AEF223A585D4115F1283999A32541A621B57E3B585D41C3D04B6182A42541'),
(99923, 71809, 44943, 1, '010500000001000000010200000006000000D013470AE2595D41E91170852F992541D806F679E3595D416DE2EB4C6299254133284C22E8595D419A95BEBD9B992541EC4FD942EF595D4111ECC784B7992541662FC799F7595D41E4C4AD2CBD9925415C03BC3BFF595D41CD93FC15AD992541'),
(153498, 40083, 70452, 1, '01050000000100000001020000000C000000D74C0F579A585D4115B141860F8D25411E16C06659585D41A0A815678C8D25412FBD241F1E585D418086FA08E18D2541D42949B1FD575D41C677DF14298E2541A1691FB59E575D41C18C71C87C8F2541EE7ECAD88E575D410A6860AEAB8F2541059E6F9961575D41904FCDF8EE8F25417069DA692F575D41AA0FFC986D9025412D88AC1918575D41008996EAE69025417B00CD90FD565D416F34059459912541410624EBE2565D4140E772CAA79125415771464571565D413D3939C1DA922541'),
(153465, 21445, 24021, 1, '010500000001000000010200000002000000ABE4D42BE65D5D413EF2E7BC7F862541BD23BFFDD15D5D4159262F5FB8862541'),
(100866, 11395, 23508, 1, '01050000000100000001020000000400000053D04FC9C15C5D418064F776A1AA254130D067CBC35C5D4162581140BEAA25415AC88540C55C5D419B564552F8AA254158005DDAC55C5D411F63B427BDAB2541'),
(100911, 189, 66776, 1, '010500000001000000010200000007000000C49EF160145C5D41C25461C8B4AA2541983B82A61C5C5D41F1584693A4AA2541A8D62E0C235C5D410833DD52A3AA25416F5134DF285C5D416A625411B8AA25410C32B25B2F5C5D41D59A0BFAD3AA25416F503C4B355C5D4169C2E82B0DAB2541708B6AEB375C5D419D08978A22AB2541'),
(156154, 23267, 3604, 1, '010500000001000000010200000006000000C7FB7DDCA75D5D4162D8DFC8598625413353B1228C5D5D41205E4785A1862541FB52279B665D5D41ABBE3BC9F186254135CA5D91375D5D4193D55B166187254143013389015D5D41656AB658E087254153B6DCB0835C5D41B5B3E11E0E892541'),
(113546, 58029, 66852, 1, '0105000000010000000102000000100000000E759C23E25A5D4130083A9491A025414E6A4AEADF5A5D414388BF6EFFA02541F499C0E5D95A5D4196D98C9E7CA12541FA3522ACCE5A5D4146994CA6DDA125410BFEF862C85A5D4185DCEA5A03A225410B832405C45A5D41C8B729AF28A225411B2E79D4C25A5D41835C7F1846A22541BAAB13F1C25A5D41ACA0D78B6AA2254151473B55C45A5D41D4B6EDBE8EA225411F667578CA5A5D4117F8588C09A3254190CA0418CE5A5D41D1BDD36E93A32541759A71E7D15A5D414B97692D2BA52541A0B93068D35A5D41C6ADDBD373A52541FB047B30D65A5D41DE3C0E3ABCA5254136821137DC5A5D41A8CB2D9412A625414F91ABEFE15A5D41986D7D68D6A62541'),
(158389, 15914, 1204, 1, '010500000001000000010200000008000000ACB1676976595D411372900F989F2541EE6D81EE72595D41ECDB18750DA02541C9C923686F595D41A0E71A4674A02541426AA4FF67595D41CBCBE343CDA0254119F3A1F262595D4101666E24E4A025413D9DED7D5E595D41DB5E3B50ECA025410C5D00AD5A595D413FCDD15BF4A025412BD1D86239595D41BBEF419DF3A02541'),
(158473, 57573, 1260, 1, '010500000001000000010200000008000000C4A2C0671B5D5D41482A5C0871A22541E58F86E5145D5D41600AC5D44DA22541AB23067DE55C5D419EB7D53441A2254164BA20D9CF5C5D41DC71FDE769A2254122DC6D9DAA5C5D41DF1C5AF418A32541677EB0EB995C5D41DECDADDFD9A32541DA615A798F5C5D41042E040D3AA5254161A30645905C5D413B5DEBF46CA52541'),
(158834, 46445, 1573, 1, '010500000001000000010200000002000000CD6FD5E0CC595D4154BCE2AD2AA625410F62D628C2595D41210C0BD95FA62541'),
(158836, 39908, 1573, 1, '010500000001000000010200000002000000F8232D138E595D41751184C472A425410F62D628C2595D41210C0BD95FA62541'),
(159490, 68455, 2217, 1, '010500000001000000010200000002000000B294350F225D5D41A79F57300FAF2541DE0AAB5D115D5D41F794F01AD0AF2541'),
(159492, 53024, 2217, 1, '0105000000010000000102000000080000003E2E4C57B75C5D41ED5BE98148AF2541488B9332C55C5D412C432365D0AF2541DFA671ADCF5C5D41DF1B36961EB0254104620959DB5C5D419A5F3C5E4FB0254153095C35E85C5D41142A3ABD62B0254132729700F55C5D412737743D60B0254138FF694D025D5D41CAD519E031B02541DE0AAB5D115D5D41F794F01AD0AF2541'),
(159973, 45624, 2791, 1, '01050000000100000001020000000800000007DBC451CB575D4194DDC9238FA72541D70896CFCD575D411F50B6C378A72541ACA62853D0575D41A1C2E6AD69A725415FEC4180D3575D41AC4609C261A7254195C3E156D7575D41F57E1E0061A72541F00A08D7DB575D417731276867A72541432CACC4DF575D411C404DCF83A7254156AAB479E0575D41EE5BC68D99A72541'),
(159974, 31906, 2791, 1, '01050000000100000001020000000200000055D3C501FB575D4151CBA9E626A7254156AAB479E0575D41EE5BC68D99A72541'),
(160607, 28660, 3724, 1, '0105000000010000000102000000070000008D59AE81E55A5D4183DD6468849D2541D6A6E611035B5D41BB589F60AA9D254133D2DFDD185B5D41CE2467B1B49D2541C84D3A31235B5D41638EC6D8CF9D25410192F6C62B5B5D41E8C4A6B2259E2541BDD696A2305B5D41DFC782C0A09E2541B9B2029A365B5D415658F0C5B49F2541'),
(161973, 14331, 6810, 1, '010500000001000000010200000003000000F4BB7AAFF45C5D41CA81DDC5DFAB25410177C20FEF5C5D41B22A69A30CAC25414C05189BEA5C5D411C439CCD14AC2541'),
(162441, 46917, 8369, 1, '01050000000100000001020000000D00000013BE0D7BB5575D410BDF88B03F972541215F58E89F575D414B13D84D7E9725413D5C682E9C575D41B9B82483A39725410EDDD45F9A575D4185BD7157C8972541938B9D7C9A575D413713BECAEC9725418997BBBDAA575D413B81285D0D992541273129EDB0575D413C4F22BD96992541C0BE496EB2575D416B351463DF992541B661A9E4B1575D415EA45336D09A254165188469BB575D4126EB41B2849B25410D480DA2BF575D41116CBCDEFF9B25416D9EB4CCC1575D413971A1AE4F9C25418EC3155AC1575D41AF53EFAA5D9D2541'),
(162966, 58358, 10550, 1, '01050000000100000001020000000E000000A0155A97095C5D4184299F5CEC9C2541F3F5F406FF5B5D4103FD3A8D549D2541380BDFEEF65B5D41891898149F9D2541D16F992BE95B5D411E2F8EE5079E2541BB5E34F0CC5B5D417CD3F4C8C39E2541024B71269F5B5D419A8801D3F79F2541FF5C3C5F965B5D41149037E633A02541009FF24C8E5B5D41B73331B885A02541D80472DE865B5D41CC271D6AD7A0254157EFCAB1805B5D418FE29F9121A1254126B6DB8A7A5B5D418ADA6B0373A125411B83E8B6755B5D416A1B9BC9D2A12541936B27BD725B5D413CCCBB501CA22541F34B87FF705B5D411737270357A22541'),
(162967, 3724, 10550, 1, '010500000001000000010200000005000000B9B2029A365B5D415658F0C5B49F25415B352EA7425B5D41B023A27A61A02541FB8A70115B5B5D41A6EAFCF320A22541F885F842625B5D410FCBE39A52A22541F34B87FF705B5D411737270357A22541'),
(163423, 53021, 13078, 1, '0105000000010000000102000000080000006ABD08B3FB585D41120A6B0248A225415198FF7EFC585D41310007EA7AA225414F48197800595D41DECD26E6A5A225417B8613EF06595D41D3838482BAA22541C9B4619C0E595D4144DB9FFFB8A2254167655DA913595D41DCC8E91EA2A225419B07180718595D417265EBC97CA225418F8280C419595D412B03161742A22541'),
(163601, 36984, 14275, 1, '01050000000100000001020000000400000084EFF45FA7595D41C9B8516009972541DB5882FF8B595D4182A2B6863A97254164429B7580595D415AD63980359725411A01C60371595D4146BA495C1B972541'),
(164057, 35635, 17490, 1, '0105000000010000000102000000020000004783C1C9295D5D41333BD41362A9254140F7D2A7365D5D4119B65CEF65A92541'),
(165005, 7177, 24891, 1, '010500000001000000010200000016000000D3232A15885C5D415F32A3CF7D8F2541E68BE926825C5D416517732718902541EDE4CF89785C5D417D014647E690254121711E12705C5D41B99C7A698891254135A58CE0605C5D41AA5EC0FB919225411A010C374C5C5D415817E473FB932541D6D501113D5C5D41AC86EF9A1395254154CB802C325C5D4192281FFBE1952541A580ABC52C5C5D41C215C6BF5796254192DF7E39265C5D4181192382F9962541A84DB750235C5D41E394D8E7589725415D6D6E11215C5D4181D5C977BF9725417EA4EF751F5C5D41F850B1E725982541EBE936C61C5C5D4151401D34CE982541E03726FC1B5C5D4188F924D66E9925410BDEA8871B5C5D4151273CD27C9A2541281C0A2E1B5C5D41ED6ECBB7DB9A2541EB86ACA3195C5D410CE68506589B2541A55FB55E175C5D4153CD364CB79B2541D610E3D7135C5D41044B441C1E9C25410C4795A70F5C5D41938819C27D9C2541A0155A97095C5D4184299F5CEC9C2541'),
(166607, 58219, 36984, 1, '01050000000100000001020000000A000000CB0F74380A5A5D4135C57A49BC952541812B2850F1595D41847902C5CF952541D9FF3173E4595D415AD4E669BC952541C4EB9A9CCA595D41EAAF8F40719525410C0184B2B8595D411B9503C67495254148AAFA1BB1595D41FC24727193952541B9BADAC3AC595D41B42A6D10C09525410A2CB820A9595D418976016E02962541C09518DCA6595D41D65A3EB46196254184EFF45FA7595D41C9B8516009972541'),
(166910, 27628, 39908, 1, '0105000000010000000102000000060000000FA0C8E748595D4174172CF396A32541976654874E595D416E438E136AA3254150AB3B8260595D41C4B8256C7CA32541F669524373595D4115DF3F62BAA3254162FC1FAA7F595D410B81212F08A42541F8232D138E595D41751184C472A42541'),
(167460, 63998, 44943, 1, '010500000001000000010200000007000000C15382C3F4595D41541258A892982541923D2082FC595D41A15DF804A79825411D7C0EBD015A5D41A015DD76CA98254151C8D01D055A5D41B4B9182804992541F5956EEF055A5D416CF80A5A3E99254104FC2D2C045A5D4140356FC2719925415C03BC3BFF595D41CD93FC15AD992541'),
(167486, 66776, 45197, 1, '01050000000100000001020000000B000000708B6AEB375C5D419D08978A22AB2541F969123A4E5C5D4183FF598AD4AB25414424E4E75B5C5D411E87CA1A22AC2541EAB1494E715C5D41982199BF7CAC25416EFFAD0E7B5C5D4136FB3BE7ADAC2541FB0BC6F2805C5D410EACBA84D8AC25414D9E558F855C5D41EFAD446203AD254112EF49288C5C5D41B29199BE43AD254180132E32905C5D41CA8DFF9A84AD254130BAAC3F925C5D41F1ED9CF8AFAD25416E94659A955C5D411A737B60E2AD2541'),
(168064, 6481, 50466, 1, '010500000001000000010200000006000000A26A4538E45C5D41B7B538662FA725412FE15958E25C5D4150E6BE5A3EA725413E4D8589E05C5D41817D182E63A7254166BC1344E15C5D4167E9333780A72541BD18B78DE45C5D415F1458C09CA725418BC7086AE85C5D41AAB4AC4AA3A72541'),
(168168, 55384, 51659, 1, '010500000001000000010200000011000000FCB97239615A5D41FEB6DE8DAAAB2541ED51377E685A5D410C41E2D7EBB425413AD4BFC0665A5D416710848A26B5254160A41463625A5D4176E4F2DE4BB52541016DF7085C5A5D41EE4F0AB55BB525413EEB5AC525595D41DFAD4F6991B525415592DF700D595D4109B10FE88EB52541A8509283B5585D417ABC096541B5254114063890A8585D410E5273E210B525410164EB05A0585D41B8F03E9FC9B425411127EAF59B585D4107B22E7A81B425419EBF6F1699585D416D2A84EB1BB42541BAD0402897585D418F7B8AF8A8B12541FA278DBE94585D4164907BF708B1254196F848D771585D416E66A48E5BAD2541EBE9EFAD6B585D41A1DA6278D9AC254190F485DE62585D41B8F737BA3AAC2541'),
(168170, 35278, 51659, 1, '01050000000100000001020000000C000000A637E472005A5D41374FDD3483AB254185F3287EF7595D41B74662F784AB254159AED55FE9595D41FE9FDE2679AB2541B4B23F77C1595D41F9C1ADC130AB2541D3D6ECDD93595D41A126C65DFFAA25414378377064595D418FF66A84EBAA2541DB21CBD34A595D41CEDE0343E9AA2541B881DCAF1E595D41EAA7EAF2F1AA25414E314CCCEE585D417B68248E18AB2541599E5A74C3585D416AAD412754AB2541B7194B1593585D415E4B58ECADAB254190F485DE62585D41B8F737BA3AAC2541'),
(168309, 75242, 53021, 1, '01050000000100000001020000000500000006BB5C440B595D413FE94F59BAA125413A4814EA04595D4169784230CAA12541EAC19B8600595D41BF5A053BE8A125410AD465D2FC585D41062513BA14A225416ABD08B3FB585D41120A6B0248A22541'),
(168904, 15683, 58688, 1, '010500000001000000010200000003000000981A104011575D41688F813EC5A325413AAC48F3A6575D41BDDA8AACA7A32541166B9AB7AE575D41217DA051C3A32541'),
(169347, 32198, 62879, 1, '010500000001000000010200000010000000A581B33B725B5D41F36C8DD088AE2541AAF6E487725B5D4143A01A20BBAF2541280A647E725B5D416AC7901580B02541EE8EB0DE735B5D41898A808870B12541096706CE775B5D41C0061C7B60B22541DCCEBFDA7A5B5D412197CC5C00B32541F77AAF25815B5D41007BA232AEB3254103AE8EF3835B5D410A6053E3FDB32541042F2F65875B5D4119CFF0734DB42541399F521E8C5B5D41C25467C49CB425414BA3BED1905B5D411F0A9ACAE4B42541FE5CBD56BC5B5D416C40D8E356B7254104BDCC2CED5B5D4190E0ED9909BA2541E3B3AF8BF45B5D4165B47D9375BA25415376FAF5FB5B5D41CEF3A021F0BA25418A0E9869015C5D4156CD617B5CBB2541'),
(169503, 6706, 64320, 1, '0105000000010000000102000000060000007CC930C41B5D5D410288B036B9A32541E7415D94EF5C5D414376F440B3A325411C4F5103DF5C5D4103E1875FCCA325414A63D5AECC5C5D416ED51FE618A42541A4DF1004C45C5D413EC4A96B79A425418DD335CABC5C5D418E1A1943E0A52541'),
(170322, 49762, 72591, 1, '0105000000010000000102000000100000002F3777AD48575D41DC3F038DDA942541D0C115DE28575D411A270A311B9525413E76780704575D41C79179017A952541D5B92EB1E3565D41A45D093ADF95254158B41B88C6565D41BD2CD0863C962541E1D2E6C22D565D418895374F269825414AC54B0DFB555D4159D04389C9982541231B0A5DD4555D41CD833A9E3E9925413D25A35BBA555D41A86D5AB78C9925417576425AA0555D41E413BFD0DA992541AEB000F578555D41667BCF283A9A2541A2C901EC50555D41A81CF9A1999A2541EA0C8D0441555D41FD701DF7B99A2541BF1CE25E32555D412DFB1EC1D29A25418615B88710555D41389A1D5AEF9A2541B868DFCCFA545D4155D96FF5FA9A2541'),
(170522, 62998, 74409, 1, '010500000001000000010200000009000000F5DB04EE00575D418DF770FB829E2541E7F35BD903575D41E2401A1EF79E25417B715D3A07575D4100A351CE309F254164BF83660E575D417B3DCC275B9F25416659D4D714575D414E40A078689F2541A3088DE782575D41E99AEE055A9F2541359DBB7F98575D4191AA9FB2229F2541AB71C7A1A4575D41160F0702199F2541E36F6E2210585D415F4BD2160B9F2541'),
(105620, 3604, 48536, 1, '01050000000100000001020000000800000053B6DCB0835C5D41B5B3E11E0E892541C11572B27C5C5D41B0DB99131E89254124A285D7715C5D410EC8307E278925413E4148495F5C5D416EDDD81E2B892541E153BB5A465C5D415579364A37892541778ED3730D5C5D41B41B2D0251892541D7485FAAE95B5D416580869966892541127684CBE85B5D418C96891867892541'),
(108938, 2882, 45624, 1, '010500000001000000010200000007000000EE5CA0E9BF575D41AB70AD4976A42541C03E0CDFBC575D41AF2224F3A9A425410D1CC3FCB9575D41072572A410A52541F3BE2884BB575D41628F4E5E00A7254189892A8BC1575D41EDB288B656A725419CED1BC6C6575D41DD0442277AA7254107DBC451CB575D4194DDC9238FA72541'),
(108339, 46301, 66776, 1, '010500000001000000010200000007000000CBB247528B5C5D41AF9D74EE8EAA25412870F7026A5C5D41D060D8DA86AA254148FD20D0665C5D415A68F57A87AA25418BDCB0B7615C5D41FB396CC58FAA2541ABC56B5D5B5C5D41131C399A9FAA254192686D74465C5D418BB4A257E5AA2541708B6AEB375C5D419D08978A22AB2541'),
(161543, 14902, 5717, 1, '010500000001000000010200000011000000B61E5F07B3585D412DBBF560BB992541C0650D86B2585D41C870CC3EE7992541A9CC0B52B3585D4104935F261A9A25417DFE596BB5585D41907AAF17549A25413E0CD542B6585D412D82C993959A2541CF70475AB4585D41C69B757E699B2541C4EB8037B5585D418F56D344B29B25418D822053B9585D41D36268FE089C2541BEF21D43BF585D41C1DA292E429C25413BAF90D4C3585D41700566755E9C2541EBE1DE45CA585D41FCA157C76B9C2541112EFC43D1585D41B558FECF5B9C2541DD01454BD6585D410E61E6A43D9C25415133F1B7D8585D414CB54D66119C2541BE9833A0DB585D41940E9DFFB19B2541FFB1D228E1585D41E4A6B5F6679B25418A156D7DE7585D41894669D5509B2541'),
(165332, 71223, 27732, 1, '010500000001000000010200000015000000A95E4F020C585D419E3D27E4C195254190CDD85404585D41A747D567C3952541A410DE8300585D419C24F173CB9525413381C822DD575D418EF2AC5264962541488309C5D8575D4190C033A889962541595E9FB4D5575D41CE6D5B07B69625413F9BD5A0D4575D41920856E4F7962541E7A5BCC5D6575D419A5FFA6940972541F1A3BA7EEA575D418C7154D6B7982541932B1981EC575D41C8266E9ED4982541AEF21480F0575D41CD2360E406992541058129A903585D41D5AD6B10C89925419EFD21A807585D412A636756FA99254137EDC7590A585D41B094BE92259A2541EFE0CEC022585D41D98DC7B9DD9B254170E9B06C25585D411EB9E3AB019C25411B93E62A4F585D412473244ACC9D25416BE412385E585D41342B7CBD369E2541F5D4D6FC6E585D418FF5B5335F9E2541E9E145A588585D418DF46707709E254155CE3DED92585D41655991977C9E2541'),
(169454, 24021, 63826, 1, '010500000001000000010200000017000000BD23BFFDD15D5D4159262F5FB8862541E9B9D8CEAD5D5D4182EB07411E872541A5F82FB7955D5D419DEA93E56B872541783CD8EC7E5D5D41D785B894C08725417AE9A9266F5D5D419909469A0C882541CB237BB3605D5D4106AE8BF466882541A0384395585D5D417A217730AA8825419AC5BD7C505D5D41BE7BAEB6F488254133271439475D5D41DFC134F06389254159E5F07E405D5D41F97A9F5FCB892541FAB7B8063B5D5D411298D9442B8A25417EC26407325D5D416868B2F9F18A254170E3939A2C5D5D41D68D7F73608B2541C663AE3C255D5D41D651F702C88B254163B04D351D5D5D41C9C42968288C2541EA547811155D5D41EB48095A648C2541DF070CA60B5D5D413FF4E58BA08C25418A7522B1FF5C5D419C730088E48C2541C74525CBF15C5D419BF2DA99218D25416B3B2BA5E75C5D41C4CDC2C2408D2541B3FFCD93DB5C5D41B0EFAF4B608D2541457AD91AD05C5D4127B42220718D2541E4C78096C45C5D41E9CF1860738D2541'),
(170151, 11736, 70733, 1, '0105000000010000000102000000050000001448CDD103595D4139CEAC9C859B254144BF53FFF9585D4192F23763DE9C2541B3737717F5585D41E289758BF49D254130783A6DF6585D4183DA6569D69E2541D3473EF6F9585D4197B02122439F2541');


WITH a AS (SELECT source FROM edges UNION select target FROM edge_table)
SELECT source AS id INTO vertices FROM a;

DROP TABLE IF EXISTS result2;
SELECT  * INTO result2 FROM pgr_lineGraphFull(
    $$SELECT id, source, target, cost
    FROM edges$$
);
SELECT count(*) FROM result2;


DROP TABLE IF EXISTS result2_vertices_pgr;
WITH foo AS (SELECT source AS id FROM result2
    UNION
    SELECT target FROM result2)
SELECT *, NULL::BIGINT AS original_id
INTO result2_vertices_pgr
FROM foo
ORDER BY id;

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;

UPDATE result2_vertices_pgr AS r SET original_id = v.id
FROM vertices AS v WHERE v.id = r.id;

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;

WITH a AS (SELECT e.id, e.original_id FROM result2_vertices_pgr AS e WHERE original_id IS NOT NULL),
b AS (SELECT * FROM result2 WHERE cost = 0 and source IN (SELECT id FROM a)),
c AS (SELECT * FROM b JOIN result2_vertices_pgr ON(source = id)),
d AS (SELECT c.source, v.original_id FROM c JOIN result2_vertices_pgr as v ON (target=v.id)),
e AS (SELECT DISTINCT c.target, c.original_id FROM c JOIN result2_vertices_pgr AS r ON(target = r.id AND r.original_id IS NULL))
UPDATE result2_vertices_pgr SET original_id = e.original_id FROM e WHERE e.target = id;

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;

WITH a AS (SELECT e.id, e.original_id FROM result2_vertices_pgr AS e WHERE original_id IS NOT NULL),
b AS (SELECT * FROM result2 WHERE cost = 0 and target IN (SELECT id FROM a)),
c AS (SELECT * FROM b JOIN result2_vertices_pgr ON(target = id)),
d AS (SELECT c.target, v.original_id FROM c JOIN result2_vertices_pgr as v ON (source=v.id)),
e AS (SELECT DISTINCT c.source, c.original_id FROM c JOIN result2_vertices_pgr AS r ON(source = r.id AND r.original_id IS NULL))
UPDATE result2_vertices_pgr SET original_id = e.original_id FROM e WHERE e.source = id;

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;

WITH a AS (SELECT id FROM result2_vertices_pgr WHERE original_id IS NULL),
b AS (SELECT source,edge FROM result2 WHERE source IN (SELECT id FROM a)),
c AS (SELECT id,source FROM edges WHERE id IN (SELECT edge FROM b))
UPDATE result2_vertices_pgr AS d SET original_id = (SELECT source FROM c WHERE c.id = (SELECT edge FROM b WHERE b.source = d.id)) WHERE id IN (SELECT id FROM a);

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;

WITH a AS (SELECT id FROM result2_vertices_pgr WHERE original_id IS NULL),
b AS (SELECT target,edge FROM result2 WHERE target IN (SELECT id FROM a)),
c AS (SELECT id,target FROM edges WHERE id IN (SELECT edge FROM b))
UPDATE result2_vertices_pgr AS d SET original_id = (SELECT target FROM c WHERE c.id = (SELECT edge FROM b WHERE b.target = d.id)) WHERE id IN (SELECT id FROM a);

SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;
